==> kimageannotator_0.5.3.orig.tar.gz: kImageAnnotator-0.5.3/translations/kImageAnnotator_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Disponi</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Porta in primo piano</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Invia in avanti</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Manda indietro</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Manda indietro</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Seleziona questo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Impostazioni Generali</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Impostazioni immagine</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Colore del testo</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Numero seme</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Fattore di offuscamento</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Ombreggiatura elemento</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Impostazione elemento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Chiudi altro</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Chiudi tutto</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Chiudi tutto a sinistra</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Chiudi tutto a destra</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Selezione strumento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Abilitato</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>A:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilità bordo e riempimento</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Bordo e riempimento</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Bordo e nessun riempimento</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Nessun bordo e nessun riempimento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Dimensione caratteri</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Sottolineatura</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Effetti immagine</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Nessun effetto</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Ombra esterna</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Scala di grigi</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Bordo</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inverti colore</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Limitato</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Quando abilitato impone la tela
per includere l&apos;immagine di sfondo.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>A:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Colore di sfondo della tela</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Ruota immagine</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° in senso orario</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° in senso antiorario</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrario</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>I valori positivi ruotano in senso orario, i valori negativi in senso antiorario.
La rotazione di moltiplicatori diversi da 90° potrebbe introdurre una perdita di qualità.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Ruotare</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Capovolgere</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Scala immagine</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantenere proporzioni</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentuale</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numero</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcatore rettangolo</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcatore ellisse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Marcatore penna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppia freccia</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Sfocatura</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Puntatore numerico</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixellato</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Puntatore testo</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Freccia testo</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Numero freccia</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicare</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Ingrandisci (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Rimpicciolisci (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Reimposta zoom (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Disponi</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Porta in primo piano</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Invia in avanti</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Manda indietro</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Manda in fondo</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Seleziona questo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Impostazioni generali</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Impostazioni immagine</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Colore del testo</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Numero seme</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Fattore di offuscamento</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Ombreggiatura elemento</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Impostazione elemento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Chiudi altro</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Chiudi tutto</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Chiudi tutto a sinistra</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Chiudi tutto a destra</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Selezione strumento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Abilitato</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>A:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilità bordo e riempimento</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Bordo e riempimento</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Bordo e nessun riempimento</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Nessun bordo e nessun riempimento</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Dimensione caratteri</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Sottolineatura</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Effetti immagine</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Nessun effetto</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Ombra esterna</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Scala di grigi</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Bordo</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inverti colore</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Limitato</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Quando abilitato forza la tela
ad includere l&apos;immagine di sfondo.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>A:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Colore di sfondo della tela</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Ruota immagine</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° in senso orario</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° in senso antiorario</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrario</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>I valori positivi ruotano in senso orario, i valori negativi in senso antiorario.
La rotazione di moltiplicatori diversi da 90° potrebbe introdurre una perdita di qualità.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Ruota</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Capovolgi</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Scala immagine</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantenere proporzioni</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentuale</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numero</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcatore rettangolo</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcatore ellisse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Marcatore penna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppia freccia</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Sfocatura</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rettangolo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Puntatore numerico</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adesivo</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixellato</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Puntatore testo</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Freccia testo</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Numero freccia</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Ingrandisci (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Rimpicciolisci (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Reimposta zoom (%1)</translation>
    </message>
</context>
</TS>
